Class: Proforma::ModelFactory
- Inherits:
-
Object
- Object
- Proforma::ModelFactory
- Defined in:
- lib/proforma/model_factory.rb
Overview
This class serves as a singleton that can make Proforma::Modeling components.
This class serves as a singleton that can make Proforma::Modeling components.